@@ -365,12 +365,21 @@ sub trim($)
   $string =~ s/\A\s+//r =~ s/\s+\Z//r
  }
 
+#1 Documented methods
+
+sub nws($)                                                                      # Normalize white space in a string to make comparisons easier
+ {my ($string) = @_;                                                            # String to normalize
+  $string =~ s/\A\s+//r =~ s/\s+\Z//r =~ s/\s+/ /gr
+ }
+
+#0
 #-------------------------------------------------------------------------------
 # Documentation
 #-------------------------------------------------------------------------------
 
-sub extractDocumentation()                                                      # Extract documentation from a perl script - sections are marked with #n, sub name and parameters are on two lines, private methods are marked with ##
- {my %s;                                                                        # Method names
+sub extractDocumentation()                                                      # Extract documentation from a perl script between lines marked with \A#n and \A# as illustrated just above this line - sections are marked with #n, sub name and parameters are on two lines, private methods are marked with ##
+ {my %methodParms;                                                              # Method names including parameters
+  my %methods;                                                                  # Method names not including parameters
   my @d;                                                                        # Documentation
   my $level = 0; my $off = 1;                                                   # Header levels
   my @l = split /\n/, readFile($0);                                             # Read this file
@@ -387,7 +396,7 @@ sub extractDocumentation()
     elsif ($L =~ /\A#/)                                                         # Switch documentation off
      {$level = 0;
      }
-    elsif ($level and $L =~ /\A\s*sub\s+(.+?)\s*#\s*(.+?)\s*\Z/)                # Documentation for a method
+    elsif ($level and $L =~ /\A\s*sub\s*(.+?)\s*#\s*(.+?)\s*\Z/)                # Documentation for a method = sub name comment
      {my ($n, $d) = ($1, $2);                                                   # Name from sub, description from comment
       next if $d =~ /\A#/;                                                      # Private method if ##
       $n =~ s/\(.+?\)//;                                                        # Method name
@@ -399,18 +408,19 @@ sub extractDocumentation()
       my $P = join ', ', @p;
       my $h = $level+$off+1;
       my $N = "$n($P)";                                                         # Method
-      $s{$N}++;                                                                 # Index method names
+      $methodParms{$N}++;                                                       # Method names including parameters
+      $methods{$n}++;                                                           # Method names not including parameters
       push @d, "\n=head$h $N\n\n $D\n";                                         # Method description
       push @d, indentString(formatTable([[qw(Parameter Description)], map{[$p[$_], $c[$_]]} keys @p]), '  ')
         if $p and $c and $c !~ /\A#/;
      }
    }
   push @d, "\n\n=head$off Index of methods by name\n";                          # Index
-  push @d, "L</$_>" for sort keys %s;                                           # Alphabetic listing of methods
+  push @d, "L</$_>" for sort keys %methodParms;                                 # Alphabetic listing of methods
   push @d, "\n";
-  writeFile("doc.data", join "\n", @d);                                         # Write file
+  writeFile("doc.data",     join "\n", @d);                                     # Write documentation file
+  writeFile("methods.data", join "\n", sort keys %methods);                     # Write methods file
  }
-# Need to apply this method to this file
 
 #-------------------------------------------------------------------------------
 # Examples
@@ -442,19 +452,21 @@ require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 
 #say STDERR formatTable(\%Data::Table::Text::);
+ extractDocumentation unless caller;                                            # Should be applied to this file
 
 @ISA          = qw(Exporter);
 @EXPORT       = qw(formatTable);
 @EXPORT_OK    = qw(checkKeys dateStamp dateTimeStamp
-extractDocumentation fileList fileSize
+extractDocumentation fileList fileSize formatTableBasic
 genLValueArrayMethods genLValueHashMethods genLValueScalarMethods genLValueScalarMethodsWithDefaultValues
 indentString
 loadArrayArrayFromLines loadArrayFromLines  loadHashArrayFromLines loadHashFromLines
-makePath
+makePath nws
 readBinaryFile readFile timeStamp trim writeBinaryFile writeFile);
 %EXPORT_TAGS  = (all=>[@EXPORT, @EXPORT_OK]);
 
-$VERSION = '1.007'; # Sunday 18 December 2016
+#$VERSION = '1.007'; # Sunday 18 December 2016
+ $VERSION = '1.008'; # Friday 30 December 2016
 
 1;
 
